@@ -15,12 +15,13 @@
 
 from abc import abstractmethod
 from collections import OrderedDict
-from collections.abc import Callable, Iterator, MutableMapping
+from collections.abc import Callable, Iterable, Iterator, MutableMapping
 from functools import partial
 from inspect import Signature, isfunction
-from typing import Any, Final, TypeVar
+from typing import Any, Final, TypeVar, final, overload
 
 from ._errors import Error, ErrorEnum
+from ._typing import SupportsKeysAndGetItem
 
 __all__: Final[list[str]] = ["Dispatcher"]
 
@@ -31,11 +32,24 @@ _Func = TypeVar("_Func", bound=Callable)
 class BaseDispatcher(MutableMapping[str, Callable]):
     __slots__: list[str] = ["_registry"]
 
-    def __init__(self) -> None:
-        self._registry: Final[OrderedDict[str, Callable]] = OrderedDict()
+    @overload
+    def __init__(self) -> None: ...
+
+    @overload
+    def __init__(self, /, **kwargs: Callable) -> None: ...
+
+    @overload
+    def __init__(self, mapping: SupportsKeysAndGetItem[str, Callable], /, **kwargs: Callable) -> None: ...
+
+    @overload
+    def __init__(self, iterable: Iterable[tuple[str, Callable]], /, **kwargs: Callable) -> None: ...
+
+    @final
+    def __init__(self, /, *args: Any, **kwargs: Any) -> None:
+        self._registry: Final[OrderedDict[str, Callable]] = OrderedDict(*args, **kwargs)
 
     def __hash__(self) -> int:
-        return hash(frozenset(objects := self.items())) ^ len(objects)
+        return hash(objects := frozenset(self.items())) ^ len(objects)
 
     def __getitem__(self, key: str, /) -> Callable:
         return self._registry[key]
@@ -60,25 +74,19 @@ class BaseDispatcher(MutableMapping[str, Callable]):
         if not isinstance(mapping, MutableMapping):
             return NotImplemented
 
-        dispatcher: Final[_Dispatcher] = self.__class__()
-        dispatcher.update(self)
-        dispatcher.update(mapping)
-        return dispatcher
+        return self.__class__(self._registry | mapping)
 
     def __ror__(self: type[_Dispatcher], mapping: MutableMapping[str, Callable], /) -> _Dispatcher:
         if not isinstance(mapping, MutableMapping):
             return NotImplemented
 
-        dispatcher: Final[_Dispatcher] = self.__class__()
-        dispatcher.update(mapping)
-        dispatcher.update(self)
-        return dispatcher
+        return self.__class__(mapping | self._registry)
 
     def __ior__(self: type[_Dispatcher], mapping: MutableMapping[str, Callable], /) -> _Dispatcher:
         if not isinstance(mapping, MutableMapping):
             return NotImplemented
 
-        self.update(mapping)
+        self._registry |= mapping
         return self
 
     @abstractmethod
