@@ -26,7 +26,7 @@ class ErrorEnum(IntEnum):
     """
     An enumeration of error codes that indicates the error type that occurred.
     """
-    #: Error occurred due the serialization to JSON or deserialization from JSON.
+    #: Error occurred due the serialization or deserialization.
     PARSE_ERROR: int = -32700
     #: Error occurred due the receiving an invalid :class:`jsonrpc.Request` object.
     INVALID_REQUEST: int = -32600
@@ -114,19 +114,19 @@ class Error(BaseError):
     def data(self) -> Any:
         """
         An any type of object that contains additional information about the error.
-        It must be JSON serializable.
-        If its value omitted, this attribute doesn't participate to JSON serialization.
+        It must be serializable (or pickle-able).
+        If its value omitted, this attribute doesn't participate to the serialization.
 
         .. warning::
             Remember that :py:data:`None` is a valid value for this attribute.
-            This means that this attribute isn't omitted and will be participate in JSON serialization.
+            This means that this attribute isn't omitted and will be participate in the serialization.
         """
         return self._data
 
     @property
     def json(self) -> dict[str, Any]:
         """
-        Returns the :py:class:`dict` object needed for JSON serialization.
+        Returns the :py:class:`dict` object needed for the serialization.
         Primarily used by the :class:`jsonrpc.Request` object.
 
         Example output::
