@@ -135,7 +135,7 @@ class Response(BaseResponse):
     def body(self) -> Any:
         """
         An any type of object that contains the payload of the successful response.
-        It must be JSON serializable.
+        It must be serializable (or pickle-able).
 
         :raises AttributeError: If the response is erroneous.
         """
@@ -176,7 +176,7 @@ class Response(BaseResponse):
     @property
     def json(self) -> dict[str, Any]:
         """
-        Returns the :py:class:`dict` object needed for JSON serialization.
+        Returns the :py:class:`dict` object needed for the serialization.
         Primarily used by the :class:`jsonrpc.WSGIHandler` instance.
 
         Example successful response::
@@ -234,7 +234,7 @@ class BatchResponse(BaseBatchResponse[Response]):
     @property
     def json(self) -> list[dict[str, Any]]:
         """
-        Returns the :py:class:`list` of :py:class:`dict` objects needed for JSON serialization.
+        Returns the :py:class:`list` of :py:class:`dict` objects needed for the serialization.
         Primarily used by the :class:`jsonrpc.WSGIHandler` instance.
 
         Example output::
