@@ -16,7 +16,7 @@
 from abc import abstractmethod
 from binascii import b2a_base64 as b64encode
 from collections import OrderedDict
-from collections.abc import Callable, Iterator, MutableMapping, MutableSequence
+from collections.abc import Callable, Iterable, Iterator, MutableMapping, MutableSequence
 from functools import partial, singledispatchmethod
 from hashlib import md5
 from http import HTTPStatus
@@ -24,14 +24,14 @@ from io import DEFAULT_BUFFER_SIZE, BytesIO
 from sys import exc_info
 from threading import Thread
 from traceback import print_exception
-from typing import Any, ClassVar, Final, TypeAlias, TypeVar
+from typing import Any, ClassVar, Final, TypeAlias, TypeGuard, TypeVar, final, overload
 
 from ._dispatcher import Dispatcher
 from ._errors import Error
 from ._request import BatchRequest, Request
 from ._response import BatchResponse, Response
 from ._serializer import JSONSerializer
-from ._typing import Headers, InputStream, OptExcInfo, StartResponse, WSGIEnvironment
+from ._typing import Headers, InputStream, OptExcInfo, StartResponse, SupportsKeysAndGetItem, WSGIEnvironment
 from ._utilities import http_rfc2822_datetime
 
 __all__: Final[list[str]] = ["WSGIHandler"]
@@ -44,8 +44,21 @@ _Handler = TypeVar("_Handler", bound="BaseWSGIHandler")
 class BaseWSGIHandler(MutableMapping[str, Any]):
     __slots__: list[str] = ["_options"]
 
-    def __init__(self) -> None:
-        self._options: Final[OrderedDict[str, Any]] = OrderedDict()
+    @overload
+    def __init__(self) -> None: ...
+
+    @overload
+    def __init__(self, /, **kwargs: Any) -> None: ...
+
+    @overload
+    def __init__(self, mapping: SupportsKeysAndGetItem[str, Any], /, **kwargs: Any) -> None: ...
+
+    @overload
+    def __init__(self, iterable: Iterable[tuple[str, Any]], /, **kwargs: Any) -> None: ...
+
+    @final
+    def __init__(self, /, *args: Any, **kwargs: Any) -> None:
+        self._options: Final[OrderedDict[str, Any]] = OrderedDict(*args, **kwargs)
 
     def __getitem__(self, key: str, /) -> Any:
         return self._options[key]
@@ -70,25 +83,19 @@ class BaseWSGIHandler(MutableMapping[str, Any]):
         if not isinstance(mapping, MutableMapping):
             return NotImplemented
 
-        handler: Final[_Handler] = self.__class__()
-        handler.update(self)
-        handler.update(mapping)
-        return handler
+        return self.__class__(self._options | mapping)
 
     def __ror__(self: type[_Handler], mapping: MutableMapping[str, Any], /) -> _Handler:
         if not isinstance(mapping, MutableMapping):
             return NotImplemented
 
-        handler: Final[_Handler] = self.__class__()
-        handler.update(mapping)
-        handler.update(self)
-        return handler
+        return self.__class__(mapping | self._options)
 
     def __ior__(self: type[_Handler], mapping: MutableMapping[str, Any], /) -> _Handler:
         if not isinstance(mapping, MutableMapping):
             return NotImplemented
 
-        self.update(mapping)
+        self._options |= mapping
         return self
 
     def __call__(self, environ: WSGIEnvironment, start_response: StartResponse, /) -> Iterator[bytes]:
@@ -252,7 +259,7 @@ class WSGIHandler(BaseWSGIHandler):
     def _(self, obj: BatchRequest, /) -> BatchResponse:
         # We need to go deeper, 'cause received a batch request object.
         # Then invoke itself recursively.
-        filterer: Callable[[_AnyResponse], bool] = lambda response: isinstance(response, Response)
+        filterer: Callable[[_AnyResponse], TypeGuard[Response]] = lambda response: isinstance(response, Response)
         return BatchResponse(filter(filterer, map(self.handle_request, obj)))
 
     @handle_request.register
